home | help
GMX-DENSMAP(1)			     GROMACS			  GMX-DENSMAP(1)

NAME
     gmx-densmap - Calculate 2D planar or axial-radial density maps

SYNOPSIS
	gmx densmap [-f [<.xtc/.trr/...>]] [-s [<.tpr/.gro/...>]] [-n [<.ndx>]]
		    [-od [<.dat>]] [-o [<.xpm>]] [-b <time>] [-e <time>]
		    [-dt <time>] [-[no]w] [-bin <real>] [-aver <enum>]
		    [-xmin <real>] [-xmax <real>] [-n1 <int>] [-n2 <int>]
		    [-amax <real>] [-rmax <real>] [-[no]mirror] [-[no]sums]
		    [-unit <enum>] [-dmin <real>] [-dmax <real>]

DESCRIPTION
     gmx  densmap  computes  2D number-density maps.  It can make planar and ax-
     ial-radial density maps.  The output .xpm file can be visualized  with  for
     instance  xv  and	can be converted to postscript with xpm2ps.  Optionally,
     output can be in text form to a .dat file with -od, instead  of  the  usual
     .xpm file with -o.

     The  default  analysis  is a 2-D number-density map for a selected group of
     atoms in the x-y plane.  The averaging direction can be  changed  with  the
     option  -aver.   When -xmin and/or -xmax are set only atoms that are within
     the limit(s) in the averaging direction are taken into account.   The  grid
     spacing is set with the option -bin.  When -n1 or -n2 is non-zero, the grid
     size  is set by this option.  Box size fluctuations are properly taken into
     account.

     When options -amax and -rmax are set, an axial-radial number-density map is
     made. Three groups should be supplied, the centers of mass of the first two
     groups define the axis, the third defines the analysis group. The axial di-
     rection goes from -amax to +amax, where the center is defined as  the  mid-
     point  between the centers of mass and the positive direction goes from the
     first to the second center of mass.  The radial direction goes  from  0  to
     rmax or from -rmax to +rmax when the -mirror option has been set.

     The  normalization of the output is set with the -unit option.  The default
     produces a true number density. Unit nm-2 leaves out the normalization  for
     the  averaging  or  the angular direction.  Option count produces the count
     for each grid cell.  When you do not want the scale in  the  output  to  go
     from  zero  to the maximum density, you can set the maximum with the option
     -dmax.

OPTIONS
     Options to specify input files:

     -f [<.xtc/.trr/...>] (traj.xtc)
	    Trajectory: xtc trr cpt gro g96 pdb tng h5md

     -s [<.tpr/.gro/...>] (topol.tpr) (Optional)
	    Structure+mass(db): tpr gro g96 pdb brk ent

     -n [<.ndx>] (index.ndx) (Optional)
	    Index file

     Options to specify output files:

     -od [<.dat>] (densmap.dat) (Optional)
	    Generic data file

     -o [<.xpm>] (densmap.xpm)
	    X PixMap compatible matrix file

     Other options:

     -b <time> (0)
	    Time of first frame to read from trajectory (default unit ps)

     -e <time> (0)
	    Time of last frame to read from trajectory (default unit ps)

     -dt <time> (0)
	    Only use frame when t MOD dt = first time (default unit ps)

     -[no]w (no)
	    View output .xvg, .xpm, .eps and .pdb files

     -bin <real> (0.02)
	    Grid size (nm)

     -aver <enum> (z)
	    The direction to average over: z, y, x

     -xmin <real> (-1)
	    Minimum coordinate for averaging

     -xmax <real> (-1)
	    Maximum coordinate for averaging

     -n1 <int> (0)
	    Number of grid cells in the first direction

     -n2 <int> (0)
	    Number of grid cells in the second direction

     -amax <real> (0)
	    Maximum axial distance from the center

     -rmax <real> (0)
	    Maximum radial distance

     -[no]mirror (no)
	    Add the mirror image below the axial axis

     -[no]sums (no)
	    Print density sums (1D map) to stdout

     -unit <enum> (nm-3)
	    Unit for the output: nm-3, nm-2, count

     -dmin <real> (0)
	    Minimum density in output

     -dmax <real> (0)
	    Maximum density in output (0 means calculate it)

SEE ALSO
     gmx(1)

     More information about GROMACS is available at <http://www.gromacs.org/>.

COPYRIGHT
     2026, GROMACS development team

2026.3				  Jun 25, 2026			  GMX-DENSMAP(1)

home | help